@@ -26,8 +26,19 @@
 #ifndef MONIT_SOCKET_H
 #define MONIT_SOCKET_H
 
-#define SOCKET_TCP  1
-#define SOCKET_UDP  2
+
+typedef enum {
+        Socket_Tcp = SOCK_STREAM,
+        Socket_Udp = SOCK_DGRAM
+} __attribute__((__packed__)) Socket_Type;
+
+
+typedef enum {
+        Socket_Unix = 0,
+        Socket_Ip,      // IP, version not specified (IPv4 or IPv6)
+        Socket_Ip4,     // IPv4 only
+        Socket_Ip6      // IPv6 only
+} __attribute__((__packed__)) Socket_Family;
 
 
 /**
@@ -38,32 +49,26 @@
  */
 
 
-typedef struct Socket_T *Socket_T;
+#define T Socket_T
+typedef struct T *T;
 
 
 /**
  * Create a new Socket opened against host:port. The returned Socket
  * is a connected socket. This method can be used to create either TCP
  * or UDP sockets and the type parameter is used to select the socket
- * type. If the use_ssl parameter is TRUE the socket is created using
+ * type. If the use_ssl parameter is true the socket is created using
  * SSL. Only TCP sockets may use SSL.
  * @param host The remote host to open the Socket against. The host
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
- * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
- * @param use_ssl if TRUE the socket is created supporting SSL
+ * @param type The socket type to use
+ * @param family The socket family to use
+ * @param use_ssl if true the socket is created supporting SSL
  * @param timeout The timeout value in milliseconds
  * @return The connected Socket or NULL if an error occurred
  */
-Socket_T socket_new(const char *host, int port, int type, int use_ssl, int timeout);
-
-
-/**
- * Factory method for creating a new Socket from a monit Port object
- * @param port The port object to create a socket from
- * @return The connected Socket or NULL if an error occurred
- */
-Socket_T socket_create(void *port);
+T Socket_new(const char *host, int port, Socket_Type type, Socket_Family family, boolean_t use_ssl, int timeout);
 
 
 /**
@@ -72,12 +77,24 @@ Socket_T socket_create(void *port);
  * @param host The remote host to open the Socket against. The host
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
- * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
+ * @param type The socket type to use
+ * @param family The socket family to use
  * @param ssl Options for SSL
  * @param timeout The timeout value in milliseconds
  * @return The connected Socket or NULL if an error occurred
  */
-Socket_T socket_create_t(const char *host, int port, int type, Ssl_T ssl, int timeout);
+T Socket_create(const char *host, int port, Socket_Type type, Socket_Family family, SslOptions_T ssl, int timeout);
+
+
+/**
+ * Create a new unix Socket for given path for connect and read.
+ * Otherwise, same as socket_new().
+ * @param path The path to unix socket
+ * @param type The socket type to use
+ * @param timeout The timeout value in milliseconds
+ * @return The connected Socket or NULL if an error occurred
+ */
+T Socket_createUnix(const char *path, Socket_Type type, int timeout);
 
 
 /**
@@ -86,150 +103,123 @@ Socket_T socket_create_t(const char *host, int port, int type, Ssl_T ssl, int ti
  * If the sslserver context is non-null the socket will support
  * ssl. This method does only support TCP sockets.
  * @param socket The accepted socket
- * @param remote_host The remote host from where the socket connection
- * originated
- * @param port The localhost port number from where the connection
- * arrived.
+ * @param addr The socket address
+ * @param addrlen The socket address length
  * @param sslserver A ssl server connection context, may be NULL
  * @return A Socket or NULL if an error occurred
  */
-Socket_T socket_create_a(int socket, const char *remote_host, int port, void *sslserver);
+T Socket_createAccepted(int socket, struct sockaddr *addr, socklen_t addrlen, void *sslserver);
 
 
 /**
  * Destroy a Socket object. Close the socket and release allocated
  * resources.
- * @param S A Socket object reference
+ * @param S A Socket_T object reference
  */
-void socket_free(Socket_T *S);
+void Socket_free(T *S);
 
 
 /**
  * Set a read/write <code>timeout</code> in milliseconds. During a read
  * operation the socket will wait up to <code>timeout</code>
  * milliseconds for data to become available if not already present.
- * @param S A Socket object
+ * @param S A Socket_T object
  * @param timeout The timeout value in milliseconds
  */
-void socket_setTimeout(Socket_T S, int timeout);
+void Socket_setTimeout(T S, int timeout);
 
 
 /**
  * Returns the socket's read/write <code>timeout</code> in milliseconds.
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The timeout value in milliseconds
  */
-int socket_getTimeout(Socket_T S);
+int Socket_getTimeout(T S);
 
 
 /**
- * Returns TRUE if the socket is ready for i|o
- * @param S A Socket object
- * @return TRUE if the socket is ready otherwise FALSE
+ * Return true if the connection is encrypted with SSL
+ * @param S A Socket_T object
+ * @return true if SSL is used otherwise false
  */
-int socket_is_ready(Socket_T S);
-
-
-/**
- * Return TRUE if the connection is encrypted with SSL
- * @param S A Socket object
- * @return TRUE if SSL is used otherwise FALSE
- */
-int socket_is_secure(Socket_T S);
-
-
-/**
- * Return TRUE if the connection is over UDP
- * @param S A Socket object
- * @return TRUE if UDP is used otherwise FALSE
- */
-int socket_is_udp(Socket_T S);
+boolean_t Socket_isSecure(T S);
 
 
 /**
  * Get the underlying socket descriptor
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The socket descriptor
  */
-int socket_get_socket(Socket_T S);
+int Socket_getSocket(T S);
 
 
 /**
  * Get the type of this socket.
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The socket type
  */
-int socket_get_type(Socket_T S);
+Socket_Type Socket_getType(T S);
 
 
 /**
  * Get the Port object used to create this socket. If no Port object
  * was used this method returns NULL.
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The Port object or NULL
  */
-void *socket_get_Port(Socket_T S);
+void *Socket_getPort(T S);
 
 
 /**
  * Get the remote port number the socket is connected to
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The remote host's port number
  */
-int socket_get_remote_port(Socket_T S);
+int Socket_getRemotePort(T S);
 
 
 /**
  * Get the remote host this socket is connected to. The host is either
  * a host name in DNS or an IP address string.
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The remote host
  */
-const char *socket_get_remote_host(Socket_T S);
+const char *Socket_getRemoteHost(T S);
 
 
 /**
  * Get the local (ephemeral) port number this socket is using.
- * @param S A Socket object
+ * @param S A Socket_T object
  * @return The port number on success otherwise -1
  */
-int socket_get_local_port(Socket_T S);
+int Socket_getLocalPort(T S);
 
 
 /**
  * Get the local interface IP address
- * @param S A Socket object
+ * @param S A Socket_T object
+ * @param host A buffer for the hostname
+ * @param hostlen A buffer length
  * @return The local host interface address or NULL if an error occurred
  */
-const char *socket_get_local_host(Socket_T S);
+const char *Socket_getLocalHost(T S, char *host, int hostlen);
 
 
 /**
- * Writes the given error message into the Socket's internal input buffer.
- * This method is used to report errors and when no more reads will be
- * attempted. Clients should use socket_getError() to retrieve the error message.
- * @param S A Socket_T object
- * @param error An error string to write to the socket's internal
- * buffer
+ * Test a Port_T object
+ * @param P A port object to test
+ * @exception IOException if test failed
  */
-void socket_setError(Socket_T S, const char *error, ...) __attribute__((format (printf, 2, 3)));
+void Socket_test(void *P);
 
 
 /**
- * Returns an error message set via socket_setError().
- * @param S A Socket_T object
- * @return An error message set on the socket
- */
-const char *socket_getError(Socket_T S);
-
-
-/**
- * Switches a connected socket to ssl.
- * @param S The already connected socket
+ * Enables SSL on a connected socket.
+ * @param S A connected Socket_T object
  * @param ssl Options for ssl
- * @return TRUE if ssl is ready otherwise FALSE
+ * @return true if ssl is ready otherwise false
  */
-int socket_switch2ssl(Socket_T S, Ssl_T ssl);
+boolean_t Socket_enableSsl(T S, SslOptions_T ssl);
 
 
 /**
@@ -239,7 +229,7 @@ int socket_switch2ssl(Socket_T S, Ssl_T ssl);
  * @param m A String to send to the client
  * @return The bytes sent or -1 if an error occured
  */
-int socket_print(Socket_T S, const char *m, ...) __attribute__((format (printf, 2, 3)));
+int Socket_print(T S, const char *m, ...) __attribute__((format (printf, 2, 3)));
 
 
 /**
@@ -249,7 +239,7 @@ int socket_print(Socket_T S, const char *m, ...) __attribute__((format (printf,
  * @param size The size of the data in b
  * @return The bytes sent or -1 if an error occured
  */
-int socket_write(Socket_T S, void *b, size_t size);
+int Socket_write(T S, void *b, size_t size);
 
 
 /**
@@ -258,7 +248,7 @@ int socket_write(Socket_T S, void *b, size_t size);
  * @param S A Socket_T object
  * @return The byte read, or -1 if the end of the stream has been reached
  */
-int socket_read_byte(Socket_T S);
+int Socket_readByte(T S);
 
 
 /**
@@ -268,7 +258,7 @@ int socket_read_byte(Socket_T S);
  * @param size The size of the buffer b
  * @return The bytes read or -1 if an error occured
  */
-int socket_read(Socket_T S, void *b, int size);
+int Socket_read(T S, void *b, int size);
 
 
 /**
@@ -282,29 +272,9 @@ int socket_read(Socket_T S, void *b, int size);
  * @return s on success, and NULL on error or when end of file occurs
  * while no characters have been read.
  */
-char *socket_readln(Socket_T S, char *s, int size);
+char *Socket_readLine(T S, char *s, int size);
 
 
-/**
- * Clears any data that exists in the input buffer
- * @param S A Socket_T object
- */
-void socket_reset(Socket_T S);
-
-
-/**
- * Shut down the writing side of the socket
- * @param S A Socket object
- * @return TRUE if the write side was shutdown otherwise FALSE
- */
-int socket_shutdown_write(Socket_T S);
-
-
-/**
- * Set TCP_NODELAY option on socket
- * @param S A Socket object
- * @return true upon successful completion, otherwise false
- */
-int socket_set_tcp_nodelay(Socket_T S);
-
+#undef T
 #endif
+
